
__version__ = '0.2.7'

from .vst_host import VstHost
from .vst_plugin import VstPlugin
from .vst_chain_worker import VstChainWorker
from .vst_exceptions import VSTPluginLoadException
from .logger import NLogger



import os
import time
import datetime
import argparse

from multiprocessing import Process

from neil_vst.vst_host import VstHost
from neil_vst.vst_plugin import VstPlugin
from neil_vst.vst_chain_worker import VstChainWorker
from neil_vst.vst_exceptions import VST_ChainWorkException


def _file_thread_worker(job_file, in_file, out_file, buffer_size, verbose, vst_info):

    try:
        worker = VstChainWorker(buffer_size=buffer_size, log_level=("DEBUG" if verbose else "INFO"), display_info=vst_info)
        worker.procces_file(job_file, in_file, out_file)
    except Exception as e:
        worker.logger.error("Chain Worker for [ %s ], original message: [ %s ]" % (os.path.basename(in_file), str(e)))


def do_all_files_in_folder(in_folder, out_folder, job_file, buffer_size, verbose, vst_info):

    in_files = [ os.path.join(in_folder, f) for f in os.listdir(in_folder) if f.endswith(('.wav', '.aiff', '.flac', '.ogg')) ]
    out_files = [ os.path.abspath(os.path.join(out_folder, os.path.basename(f))) for f in in_files ]

    work_threads = []
    for in_file, out_file in zip(in_files, out_files):
        work_threads.append(
            Process(target=_file_thread_worker, args=(job_file, in_file, out_file, buffer_size, verbose, vst_info))
        )

    [ wt.start() for wt in work_threads ]
    [ wt.join() for wt in work_threads ]


def parse_args():
    parser = argparse.ArgumentParser(description=__doc__)
    parser.add_argument('-f', '--folder', type=str, default=".", help='folder with input audio files (default: %(default)s)')
    parser.add_argument('-j', '--job', type=str, help='JSON job file')
    parser.add_argument('-o', '--output', type=str, default="./out", help='output folder for audio files (default: %(default)s)')
    parser.add_argument('-b', '--buffersize', type=int, default=8096, help='buffer size in bytes [1024...65536] (default: %(default)s)')
    parser.add_argument('-v', '--verbose', action="store_true", help='verbose logging (default: %(default)s)')
    parser.add_argument('-i', '--info', action="store_true", help='show all parameters info for loaded VST (default: %(default)s)')

    args = parser.parse_args()

    if args.buffersize < 1024 or args.buffersize > 65536:
        parser.error('blocksize must be in range [1024...65536]')

    return args


def main():
    args = parse_args()

    start_time = time.time()
    print( "[ MAIN START ]" )

    do_all_files_in_folder(args.folder, args.output, args.job, args.buffersize, args.verbose, args.info)

    end_time = datetime.timedelta( seconds=(time.time()-start_time).split(".")[0] )
    print( "[ MAIN END ] - Elapsed time: [ %s ]" % end_time )


if __name__ == '__main__':
    main()





import setuptools
from pathlib import Path
import os
import os.path
from Cython.Build import cythonize


__version__ = '0.2.7'

this_directory = os.path.dirname(__file__)
packages = setuptools.find_packages()
print(this_directory, packages)


ext_modules = cythonize( [
        'neil_vst/vst_host.pyx',
        'neil_vst/vst_plugin.pyx',
        'neil_vst/vst_chain_worker.pyx',
        'neil_vst/logger.pyx',
        'neil_vst/vst_exceptions.pyx'
],
        compiler_directives={
            'language_level': "3"
        },

)

# workaround for https://github.com/cython/cython/issues/1480
for module in ext_modules:
    module.include_dirs = [ this_directory + "/neil_vst/vst_sdk_includes" ]

with open( str(this_directory) + '/README.md', "r" ) as f:
    long_description = f.read()

setuptools.setup(
    name='neil_vst',
    version=__version__,
    ext_modules=ext_modules,
    packages=packages,
    license='MIT',
    description='Cython-based simple VST 2.4 Host and VST Plugins wrapper. Fast work and clean python object-oriented interface',
    long_description=long_description,
    long_description_content_type='text/markdown',
    install_requires=[
       'Cython>=0.29.19',
       'SoundFile>=0.10.3.post1',
       'numpy==1.19.0'
    ],
    entry_points={
        "console_scripts": [
            "neil_vst_chain=neil_vst.cli_script:main",
        ]
    },
    include_package_data=True,

    author='Vladislav Kamenev',  # Type in your name
    author_email='',
    url='https://github.com/LeftRadio/py-neil-vst',
    keywords=['vst', 'plugin', 'cython'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9'
    ]
)
